@@ -11,10 +11,15 @@
 #include <QWidget>
 
 #include <kparts/part.h>
-#include <kparts/browserextension.h>
+
+#include <QtGlobal>
+#include <KParts/NavigationExtension>
 #include <kio/job.h>
 #include <kfileitem.h>
 
+#include "browserarguments.h"
+#include "windowargs.h"
+
 #ifndef KONQSIDEBARPLUGIN_EXPORT
 # if defined(MAKE_KONQSIDEBARPLUGIN_LIB)
 /* We are building this library */
@@ -48,7 +53,7 @@ public:
 
     /**
      * Enable/disable a standard konqueror action (cut, copy, paste, print)
-     * See KParts::BrowserExtension::enableAction
+     * See KParts::NavigationExtension::enableAction
      */
     void enableCopy(bool enabled);
     void enableCut(bool enabled);
@@ -59,9 +64,9 @@ public:
 
     void showPopupMenu(const QPoint &global, const KFileItemList &items,
                        const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
-                       const KParts::BrowserArguments &browserArgs = KParts::BrowserArguments(),
-                       KParts::BrowserExtension::PopupFlags flags = KParts::BrowserExtension::DefaultPopupItems,
-                       const KParts::BrowserExtension::ActionGroupMap &actionGroups = KParts::BrowserExtension::ActionGroupMap());
+                       const BrowserArguments &browserArgs = BrowserArguments(),
+                       KParts::NavigationExtension::PopupFlags flags = KParts::NavigationExtension::DefaultPopupItems,
+                       const KParts::NavigationExtension::ActionGroupMap &actionGroups = KParts::NavigationExtension::ActionGroupMap());
 
 protected:
     /**
@@ -94,13 +99,13 @@ Q_SIGNALS:
      * Ask konqueror to open @p url.
      */
     void openUrlRequest(const QUrl &url, const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
-                        const KParts::BrowserArguments &browserArgs = KParts::BrowserArguments());
+                        const BrowserArguments &browserArgs = BrowserArguments());
     /**
      * Ask konqueror to create a new window (or tab, see BrowserArguments) for @p url.
      */
     void createNewWindow(const QUrl &url, const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
-                         const KParts::BrowserArguments &browserArgs = KParts::BrowserArguments(),
-                         const KParts::WindowArgs & = KParts::WindowArgs());
+                         const BrowserArguments &browserArgs = BrowserArguments(),
+                         const WindowArgs & = WindowArgs());
 
     /**
      * Ask konqueror to show the standard popup menu for the given @p items.
@@ -108,9 +113,9 @@ Q_SIGNALS:
     void popupMenu(KonqSidebarModule *module,
                    const QPoint &global, const KFileItemList &items,
                    const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
-                   const KParts::BrowserArguments &browserArgs = KParts::BrowserArguments(),
-                   KParts::BrowserExtension::PopupFlags flags = KParts::BrowserExtension::DefaultPopupItems,
-                   const KParts::BrowserExtension::ActionGroupMap &actionGroups = KParts::BrowserExtension::ActionGroupMap());
+                   const BrowserArguments &browserArgs = BrowserArguments(),
+                   KParts::NavigationExtension::PopupFlags flags = KParts::NavigationExtension::DefaultPopupItems,
+                   const KParts::NavigationExtension::ActionGroupMap &actionGroups = KParts::NavigationExtension::ActionGroupMap());
 
     // TODO
     void submitFormRequest(const char *, const QString &, const QByteArray &, const QString &, const QString &, const QString &);
