@@ -25,7 +25,7 @@
 #include "konqview.h"
 #include "konqviewmanager.h"
 #include "konqmisc.h"
-#include "konqsettingsxt.h"
+#include "konqsettings.h"
 #include "konqframevisitor.h"
 
 #include <kacceleratormanager.h>
@@ -59,12 +59,12 @@ KonqFrameTabs::KonqFrameTabs(QWidget *parent, KonqFrameContainerBase *parentCont
     m_pActiveChild = nullptr;
     m_pViewManager = viewManager;
 
-    m_permanentCloseButtons = KonqSettings::permanentCloseButton();
+    m_permanentCloseButtons = Konq::Settings::permanentCloseButton();
     if (m_permanentCloseButtons) {
         setTabsClosable(true);
     }
     tabBar()->setSelectionBehaviorOnRemove(
-        KonqSettings::tabCloseActivatePrevious() ? QTabBar::SelectPreviousTab : QTabBar::SelectRightTab);
+        Konq::Settings::tabCloseActivatePrevious() ? QTabBar::SelectPreviousTab : QTabBar::SelectRightTab);
 
     applyTabBarPositionOption();
 
@@ -72,7 +72,7 @@ KonqFrameTabs::KonqFrameTabs(QWidget *parent, KonqFrameContainerBase *parentCont
     connect(this, SIGNAL(removeTabPopup()),
             m_pViewManager->mainWindow(), SLOT(slotRemoveTabPopup()));
 
-    if (KonqSettings::addTabButton()) {
+    if (Konq::Settings::addTabButton()) {
         m_leftWidget = new NewTabToolButton(this);
         connect(m_leftWidget, SIGNAL(clicked()),
                 m_pViewManager->mainWindow(), SLOT(slotAddTab()));
@@ -85,7 +85,7 @@ KonqFrameTabs::KonqFrameTabs(QWidget *parent, KonqFrameContainerBase *parentCont
         m_leftWidget->setToolTip(i18n("Open a new tab"));
         setCornerWidget(m_leftWidget, Qt::TopLeftCorner);
     }
-    if (KonqSettings::closeTabButton()) {
+    if (Konq::Settings::closeTabButton()) {
         m_rightWidget = new QToolButton(this);
         connect(m_rightWidget, SIGNAL(clicked()),
                 m_pViewManager->mainWindow(), SLOT(slotRemoveTab()));
@@ -311,9 +311,9 @@ void KonqFrameTabs::refreshSubPopupMenuTab()
     int i = 0;
     m_pSubPopupMenuTab->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")),
                                   i18n("&Reload All Tabs"),
+                                  m_pViewManager->mainWindow()->action("reload_all_tabs")->shortcut(),
                                   m_pViewManager->mainWindow(),
-                                  SLOT(slotReloadAllTabs()),
-                                  m_pViewManager->mainWindow()->action("reload_all_tabs")->shortcut());
+                                  SLOT(slotReloadAllTabs()));
     m_pSubPopupMenuTab->addSeparator();
     for (KonqFrameBase *frameBase: m_childFrameList) {
         KonqFrame *frame = dynamic_cast<KonqFrame *>(frameBase);
@@ -333,9 +333,9 @@ void KonqFrameTabs::refreshSubPopupMenuTab()
     m_popupActions[QStringLiteral("closeothertabs")] =
         m_pSubPopupMenuTab->addAction(QIcon::fromTheme(QStringLiteral("tab-close-other")),
                                       i18n("Close &Other Tabs"),
+                                      m_pViewManager->mainWindow()->action("removeothertabs")->shortcut(),
                                       m_pViewManager->mainWindow(),
-                                      SLOT(slotRemoveOtherTabsPopup()),
-                                      m_pViewManager->mainWindow()->action("removeothertabs")->shortcut());
+                                      SLOT(slotRemoveOtherTabsPopup()));
 }
 
 void KonqFrameTabs::slotCloseRequest(int idx)
@@ -454,19 +454,19 @@ void KonqFrameTabs::initPopupMenu()
     m_pPopupMenu = new QMenu(this);
     m_popupActions[QStringLiteral("newtab")] = m_pPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("tab-new")),
                                i18n("&New Tab"),
+                               m_pViewManager->mainWindow()->action("newtab")->shortcut(),
                                m_pViewManager->mainWindow(),
-                               SLOT(slotAddTab()),
-                               m_pViewManager->mainWindow()->action("newtab")->shortcut());
+                               SLOT(slotAddTab()));
     m_popupActions[QStringLiteral("duplicatecurrenttab")] = m_pPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("tab-duplicate")),
                                             i18n("&Duplicate Tab"),
+                                            m_pViewManager->mainWindow()->action("duplicatecurrenttab")->shortcut(),
                                             m_pViewManager->mainWindow(),
-                                            SLOT(slotDuplicateTabPopup()),
-                                            m_pViewManager->mainWindow()->action("duplicatecurrenttab")->shortcut());
+                                            SLOT(slotDuplicateTabPopup()));
     m_popupActions[QStringLiteral("reload")] = m_pPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")),
                                i18n("&Reload Tab"),
+                               m_pViewManager->mainWindow()->action("reload")->shortcut(),
                                m_pViewManager->mainWindow(),
-                               SLOT(slotReloadPopup()),
-                               m_pViewManager->mainWindow()->action("reload")->shortcut());
+                               SLOT(slotReloadPopup()));
     m_pPopupMenu->addSeparator();
     m_pSubPopupMenuTab = new QMenu(this);
     m_popupActions[QStringLiteral("othertabs")] = m_pPopupMenu->addMenu(m_pSubPopupMenuTab);
@@ -476,15 +476,15 @@ void KonqFrameTabs::initPopupMenu()
     m_pPopupMenu->addSeparator();
     m_popupActions[QStringLiteral("breakoffcurrenttab")] = m_pPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("tab-detach")),
                                            i18n("D&etach Tab"),
+                                           m_pViewManager->mainWindow()->action("breakoffcurrenttab")->shortcut(),
                                            m_pViewManager->mainWindow(),
-                                           SLOT(slotBreakOffTabPopup()),
-                                           m_pViewManager->mainWindow()->action("breakoffcurrenttab")->shortcut());
+                                           SLOT(slotBreakOffTabPopup()));
     m_pPopupMenu->addSeparator();
     m_popupActions[QStringLiteral("removecurrenttab")] = m_pPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("tab-close")),
                                          i18n("&Close Tab"),
+                                         m_pViewManager->mainWindow()->action("removecurrenttab")->shortcut(),
                                          m_pViewManager->mainWindow(),
-                                         SLOT(slotRemoveTabPopup()),
-                                         m_pViewManager->mainWindow()->action("removecurrenttab")->shortcut());
+                                         SLOT(slotRemoveTabPopup()));
     connect(this, SIGNAL(contextMenu(QWidget*,QPoint)),
             SLOT(slotContextMenu(QWidget*,QPoint)));
     connect(this, SIGNAL(contextMenu(QPoint)),
@@ -602,7 +602,7 @@ KonqFrameBase *KonqFrameTabs::currentTab() const
 
 bool KonqFrameTabs::eventFilter(QObject *watched, QEvent *event)
 {
-    if (KonqSettings::mouseMiddleClickClosesTab()) {
+    if (Konq::Settings::mouseMiddleClickClosesTab()) {
         QTabBar *bar = tabBar();
         if (watched == bar &&
                 (event->type() == QEvent::MouseButtonPress ||
@@ -628,7 +628,7 @@ void KonqFrameTabs::reparseConfiguration()
 
 void KonqFrameTabs::applyTabBarPositionOption()
 {
-    int tabBarPosition = KonqSettings::tabBarPosition();
+    int tabBarPosition = Konq::Settings::tabBarPosition();
     if (tabBarPosition < North || tabBarPosition > East) {
         tabBarPosition = 0;
     }
